*###########################################################################################
*### Local Linear Regressions

*### PATHS (Put the file path where you downloaded the contents of the zip file)
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
global path    ".../Example5"
*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*### VERSION TRACK
/*
Created by Pavel Luengas
Last update: Nov 25, 2022

Version 1.0 - Nov 25, 2022
   - File created 

Contact me for comments and questions:
pavel@pavellsierra.com */

*===========================================================================================

version 14
set more off

*=================================================================================
*== FIGURE

use "$path/Dataset.dta", clear

*############################################
*## Define a grid

* The range of both X-axis variables is from 0 to 1
* Create a grid to estimate the local linear regression
* at 100 equally spaced points in this range

****************************************
*** Define grid [0-1, equally spaced]
cap drop grid
gen grid = (_n -1) /100 if _n<=101

sum grid

*##########################################
*### PANEL A - FIRST DISCOUNT FACTOR

* Local Linear Regression
lpoly y  dfactor_a, degree(1)  noscatter ci // bw = 0.13
* Histogram of 'dfactor_a' 
histogram dfactor_a, bcolor(none) lcolor(gs10) percent bin(40) ylabel(0(20)80, labsize(small) angle(horizontal))

* Local Linear Regression - Save estimates and standard error
lpoly y  dfactor_a, degree(1) bw(.13) noscatter ci at(grid) gen(y_a) se(se_a)
	gen y_a_lower = y_a - 1.96*se_a
	gen y_a_upper = y_a + 1.96*se_a

* Graph
sort grid
set scheme s1mono  // Get rid of all color
twoway /*
	*/ (histogram dfactor_a, 	bcolor(gs10) lcolor(gs12) percent bin(40) yaxis(2)) /*
	*/ (line y_a grid, 			lpattern(dot) lcolor(dknavy) 	lwidth(medium) yaxis(1))  /*
	*/ (line y_a_lower grid, 	lcolor(dknavy) lpattern(solid) lwidth(medium) yaxis(1))  /*
	*/ (line y_a_upper grid, 	lcolor(dknavy) lpattern(solid) lwidth(medium) yaxis(1))  /*

   */ , /*
   */ plotr(m(zero)) plotregion(lwidth(vthin) lcolor(black)) /* 
   */ aspect(0.95) /* 
   */   /*
   */ title("Discount Factor: Wages" " "  , size(medlarge))  /*
   */   /*
   */ ytitle("Use of Commitment" "Savings Strategies=1", size(medium) axis(1)) /*
   */ yscale(range(0 .35) lwidth(vthin) lcolor(black) axis(1)) /*
   */ ylabel(0(.05).35, labsize(medium)  angle(horizontal) tlwidth(vthin) axis(1)) /*
   */   /*
   */ ytitle("Histogram of the" "Discount Factor (percent)", size(medium) axis(2)) /*
   */ yscale(range(0 80) lwidth(vthin) lcolor(black) axis(2)) /*
   */ ylabel(0(20)80, labsize(medium)  angle(horizontal) tlwidth(vthin) axis(2)) /*
   */   /*
   */ xtitle("Earnings per hour (EPH) " " / [(EPH) + (Partner's EPH)] ", size(medium))  /*
   */ xscale(range(0 1) lwidth(vthin) lcolor(black)) /*
   */ xlabel(0(.25)1, tlwidth(vthin) labsize(medium)) /*
   */   /*
   */ xline(.25, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */ xline(.50, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */ xline(.75, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */   /* 
   */ legend(off) /*
   */ note("Local linear regression:" "Bandwidth=0.13, Kernel=Epanechnikov", size(small))

graph export "$path/Figs/PanelA.eps", replace 
graph save Graph "$path/PanelA.gph", replace


*##########################################
*### PANEL B - SECOND DISCOUNT FACTOR

* Local Linear Regression
lpoly y  dfactor_b, degree(1)  noscatter ci // bw = 0.22
* Histogram of 'dfactor_a' 
histogram dfactor_b, bcolor(none) lcolor(gs10) percent bin(40) ylabel(0(5)15, labsize(small) angle(horizontal))

* Local Linear Regression - Save estimates and standard error
lpoly y  dfactor_b, degree(1) bw(.22) noscatter ci at(grid) gen(y_b) se(se_b)
	gen y_b_lower = y_b - 1.96*se_b
	gen y_b_upper = y_b + 1.96*se_b

* Graph
sort grid
set scheme s1mono  // Get rid of all color
twoway /*
	*/ (histogram dfactor_b, 	bcolor(gs10) lcolor(gs12) percent bin(40) yaxis(2)) /*
	*/ (line y_b grid, 			lpattern(dot) lcolor(dknavy) 	lwidth(medium) yaxis(1))  /*
	*/ (line y_b_lower grid, 	lcolor(dknavy) lpattern(solid) lwidth(medium) yaxis(1))  /*
	*/ (line y_b_upper grid, 	lcolor(dknavy) lpattern(solid) lwidth(medium) yaxis(1))  /*

   */ , /*
   */ plotr(m(zero)) plotregion(lwidth(vthin) lcolor(black)) /* 
   */ aspect(0.95) /* 
   */   /*
   */ title("Discount Factor: Education" "of Family"  , size(medlarge))  /*
   */   /*
   */ ytitle("Use of Commitment" "Savings Strategies=1", size(medium) axis(1)) /*
   */ yscale(range(0 .35) lwidth(vthin) lcolor(black) axis(1)) /*
   */ ylabel(0(.05).35, labsize(medium)  angle(horizontal) tlwidth(vthin) axis(1)) /*
   */   /*
   */ ytitle("Histogram of the" "Discount Factor (percent)", size(medium) axis(2)) /*
   */ yscale(range(0 15) lwidth(vthin) lcolor(black) axis(2)) /*
   */ ylabel(0(5)15, labsize(medium)  angle(horizontal) tlwidth(vthin) axis(2)) /*
   */   /*
   */ xtitle("Years of Education of Family (YEF) " "/ [(YEF) + (Partner's YEF)] ", size(medium))  /*
   */ xscale(range(0 1) lwidth(vthin) lcolor(black)) /*
   */ xlabel(0(.25)1, tlwidth(vthin) labsize(medium)) /*
   */   /*
   */ xline(.25, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */ xline(.50, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */ xline(.75, lwidth(vthin) lpattern(dot) lcolor(cranberry)) /* 
   */   /* 
   */ legend(off) /*
   */ note("Local linear regression:" "Bandwidth=0.22, Kernel=Epanechnikov", size(small))

graph export "$path/Figs/PanelB.eps", replace 
graph save Graph "$path/PanelB.gph", replace

